@@ -62,7 +62,7 @@ update_no_turbo (PpdDriverIntelPstate *pstate)
       turbo_disabled = TRUE;
   }
 
-  g_object_set (G_OBJECT (pstate), "performance-inhibited",
+  g_object_set (G_OBJECT (pstate), "performance-degraded",
                 turbo_disabled ? "high-operating-temperature" : NULL,
                 NULL);
 }
@@ -107,8 +107,7 @@ open_policy_dir (void)
 }
 
 static gboolean
-ppd_driver_intel_pstate_probe (PpdDriver  *driver,
-                               PpdProfile *prev_profile)
+ppd_driver_intel_pstate_probe (PpdDriver  *driver)
 {
   PpdDriverIntelPstate *pstate = PPD_DRIVER_INTEL_PSTATE (driver);
   g_autoptr(GDir) dir = NULL;
