@@ -16,26 +16,22 @@
  * @Title: Profile Drivers
  *
  * Profile drivers are the implementation of the different profiles for
- * the whole system. A driver will implement support for one or more
- * profiles, usually one or both of the `performance` and `power-saver`
- * profiles, for a particular system. Only one driver will be selected and
- * running per profile.
+ * the whole system. A driver will need to implement support `power-saver`
+ * and `balanced` at a minimum.
  *
- * If no system-specific driver is available, some placeholder `balanced`
- * and `power-saver` drivers will be put in place, and the `performance`
- * profile will be unavailable.
+ * If no system-specific driver is available, a placeholder driver
+ * will be put in place, and the `performance` profile will be unavailable.
  *
- * Common implementation of drivers might be:
- * - a driver handling all three profiles, relying on a firmware feature
- *   exposed in the kernel,
- * - a driver that only implements the `performance` profile on a particular
- *   system it has intimate knowledge of, leaving the `balanced` and
- *   `power-saver` profiles using placeholder
+ * There should not be a need to implement system-specific drivers, as the
+ * [`platform_profile`](https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/tree/Documentation/ABI/testing/sysfs-platform_profile)
+ * kernel API offers a way to implement system-specific profiles which
+ * `power-profiles-daemon` can consume.
  *
  * When a driver implements the `performance` profile, it might set the
- * #PpdDriver:performance-inhibited property if the profile isn't available for any
- * reason, such as thermal limits being reached, or because a part of the
- * user's body is too close for safety, for example.
+ * #PpdDriver:performance-degraded property if the profile isn't running to
+ * its fullest performance for any reason, such as thermal limits being
+ * reached, or because a part of the user's body is too close for safety,
+ * for example.
  */
 
 typedef struct
@@ -43,14 +39,14 @@ typedef struct
   char          *driver_name;
   PpdProfile     profiles;
   gboolean       selected;
-  char          *performance_inhibited;
+  char          *performance_degraded;
 } PpdDriverPrivate;
 
 enum {
   PROP_0,
   PROP_DRIVER_NAME,
   PROP_PROFILES,
-  PROP_PERFORMANCE_INHIBITED
+  PROP_PERFORMANCE_DEGRADED
 };
 
 enum {
@@ -81,9 +77,9 @@ ppd_driver_set_property (GObject        *object,
   case PROP_PROFILES:
     priv->profiles = g_value_get_flags (value);
     break;
-  case PROP_PERFORMANCE_INHIBITED:
-    g_clear_pointer (&priv->performance_inhibited, g_free);
-    priv->performance_inhibited = g_value_dup_string (value);
+  case PROP_PERFORMANCE_DEGRADED:
+    g_clear_pointer (&priv->performance_degraded, g_free);
+    priv->performance_degraded = g_value_dup_string (value);
     break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
@@ -106,8 +102,8 @@ ppd_driver_get_property (GObject        *object,
   case PROP_PROFILES:
     g_value_set_flags (value, priv->profiles);
     break;
-  case PROP_PERFORMANCE_INHIBITED:
-    g_value_set_string (value, priv->performance_inhibited);
+  case PROP_PERFORMANCE_DEGRADED:
+    g_value_set_string (value, priv->performance_degraded);
     break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
@@ -121,7 +117,7 @@ ppd_driver_finalize (GObject *object)
 
   priv = PPD_DRIVER_GET_PRIVATE (PPD_DRIVER (object));
   g_clear_pointer (&priv->driver_name, g_free);
-  g_clear_pointer (&priv->performance_inhibited, g_free);
+  g_clear_pointer (&priv->performance_degraded, g_free);
 
   G_OBJECT_CLASS (ppd_driver_parent_class)->finalize (object);
 }
@@ -197,15 +193,15 @@ ppd_driver_class_init (PpdDriverClass *klass)
                                                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
   /**
-   * PpdDriver:performance-inhibited:
+   * PpdDriver:performance-degraded:
    *
    * If set to a non-%NULL value, the reason why the performance profile is unavailable.
    * The value must be one of the options listed in the D-Bus API reference.
    */
-  g_object_class_install_property (object_class, PROP_PERFORMANCE_INHIBITED,
-                                   g_param_spec_string("performance-inhibited",
-                                                       "Performance Inhibited",
-                                                       "Why the performance profile is inhibited, if set",
+  g_object_class_install_property (object_class, PROP_PERFORMANCE_DEGRADED,
+                                   g_param_spec_string("performance-degraded",
+                                                       "Performance Degraded",
+                                                       "Why the performance profile is degraded, if set",
                                                        NULL,
                                                        G_PARAM_READWRITE));
 }
@@ -216,24 +212,14 @@ ppd_driver_init (PpdDriver *self)
 }
 
 PpdProbeResult
-ppd_driver_probe (PpdDriver  *driver,
-                  PpdProfile *previous_profile)
+ppd_driver_probe (PpdDriver  *driver)
 {
-  PpdProfile profile = PPD_PROFILE_UNSET;
-  PpdProbeResult ret;
-
   g_return_val_if_fail (PPD_IS_DRIVER (driver), FALSE);
-  g_return_val_if_fail (previous_profile != NULL, FALSE);
 
   if (!PPD_DRIVER_GET_CLASS (driver)->probe)
     return PPD_PROBE_RESULT_SUCCESS;
 
-  ret = PPD_DRIVER_GET_CLASS (driver)->probe (driver, &profile);
-  if (ret == PPD_PROBE_RESULT_SUCCESS &&
-      profile != PPD_PROFILE_UNSET &&
-      ppd_profile_has_single_flag (profile))
-    *previous_profile = profile;
-  return ret;
+  return PPD_DRIVER_GET_CLASS (driver)->probe (driver);
 }
 
 gboolean
@@ -285,18 +271,18 @@ ppd_driver_get_selected (PpdDriver *driver)
 }
 
 const char *
-ppd_driver_get_performance_inhibited (PpdDriver *driver)
+ppd_driver_get_performance_degraded (PpdDriver *driver)
 {
   PpdDriverPrivate *priv;
 
   g_return_val_if_fail (PPD_IS_DRIVER (driver), NULL);
 
   priv = PPD_DRIVER_GET_PRIVATE (driver);
-  return priv->performance_inhibited ? priv->performance_inhibited : "";
+  return priv->performance_degraded ? priv->performance_degraded : "";
 }
 
 gboolean
-ppd_driver_is_performance_inhibited (PpdDriver *driver)
+ppd_driver_is_performance_degraded (PpdDriver *driver)
 {
   PpdDriverPrivate *priv;
 
@@ -304,7 +290,7 @@ ppd_driver_is_performance_inhibited (PpdDriver *driver)
 
   priv = PPD_DRIVER_GET_PRIVATE (driver);
 
-  return (priv->performance_inhibited != NULL);
+  return (priv->performance_degraded != NULL);
 }
 
 void
@@ -323,14 +309,14 @@ const char *
 ppd_profile_activation_reason_to_str (PpdProfileActivationReason reason)
 {
   switch (reason) {
-  case PPD_PROFILE_ACTIVATION_REASON_INHIBITION:
-    return "inhibition";
   case PPD_PROFILE_ACTIVATION_REASON_INTERNAL:
     return "internal";
   case PPD_PROFILE_ACTIVATION_REASON_RESET:
     return "reset";
   case PPD_PROFILE_ACTIVATION_REASON_USER:
     return "user";
+  case PPD_PROFILE_ACTIVATION_REASON_PROGRAM_HOLD:
+    return "program-hold";
   default:
     g_assert_not_reached ();
   }
